==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/admin/messages/cs/settings.php <==
<?php

return [
    '1 month' => '1 měsíc',
    '1 week' => '1 týden',
    '1 year' => '1 rok',
    '2 weeks' => '2 týdny',
    '3 months' => '3 měsíce',
    '6 months' => '6 měsíců',
    '<strong>Confirm</strong> image deletion' => '<strong>Potvrzení </strong> smazání obrázku',
    'Add OEmbed provider' => 'Přidat poskytovatele OEmbed ',
    'Add new provider' => 'Přidat nového ověřovatele',
    'Advanced Settings' => 'Rozšířená nastavení',
    'Allow Self-Signed Certificates?' => 'Povolit self-signed certifikáty?',
    'Allowed file extensions' => 'Povolené přípony souborů',
    'Appearance Settings' => 'Nastavení vzhledu',
    'Auto format based on user language - Example: {example}' => 'Automatická formát uživatelského jazyka - Přiklad: {example}',
    'Back to overview' => 'Zpět na přehled',
    'Base URL' => 'URL adresa',
    'Comma separated list. Leave empty to allow all.' => 'Jednotlivé přípony oddělte čárkou. Pro povolení všech přípon nechejte prázdné.',
    'Currently no provider active!' => 'Momentálně není aktivní žádný ověřovatel!',
    'Currently there are {count} records in the database dating from {dating}.' => 'V současné době existují {count} záznamy v databázi datované od {dating}.',
    'Dashboard' => 'Nástěnka',
    'Date input format' => 'Formát data',
    'Default language' => 'Výchozí jazyk',
    'Default pagination size (Entries per page)' => 'Výchozí stránkování (položek na stránku)',
    'Default stream content order' => 'Výchozí pořadí obsahu ',
    'Delete' => 'Smazat',
    'E-Mail' => 'E-mail',
    'E-Mail sender address' => 'Adresa odesílatele',
    'E-Mail sender name' => 'Jméno odesílatele',
    'E.g. http://example.com/humhub' => 'Např. http://example.com/humhub',
    'Edit OEmbed provider' => 'Editovat poskytovatele OEmbed',
    'Enable user friendship system' => 'Povolit přátelství',
    'Enabled' => 'Zapnuto',
    'Enabled OEmbed providers' => 'Povolení poskytovatelů služby OEmbed',
    'Endpoint Url' => 'URL veřejné API provozovatele',
    'Firstname Lastname (e.g. John Doe)' => 'Jméno Příjmení (např. Jan Novák)',
    'Friendship' => 'Přátelství',
    'General' => 'Obecné',
    'General Settings' => 'Hlavní nastavení',
    'HTML tracking code' => 'Sledovací kód',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Zde můžete nastavit proces registrace a další uživatelská nastavení pro Vaší síť.',
    'Here you can configure basic settings of your social network.' => 'Zde můžete nastavit základní nastavení Vaší sítě.',
    'Horizontal scrolling images on a mobile device' => 'Horizontalní posun obrázků na mobilních zařízeních',
    'Last visit' => 'Poslední návštěva',
    'Logo upload' => 'Logo',
    'Mail Transport Type' => 'Typ přenosu',
    'Maximum allowed age for logs.' => 'Maximální povolená doba logování',
    'Maximum upload file size (in MB)' => 'Maximální velikost nahrávaného souboru (v MB)',
    'Name of the application' => 'Název aplikace',
    'No Proxy Hosts' => 'Bez hostování proxy',
    'Notification Settings' => 'Nastavení upozornění',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Staré protokoly mohou podstatně zvýšit velikost vaší databáze a přitom poskytnout jen málo informací.',
    'PHP reported a maximum of {maxUploadSize} MB' => 'Nastavení maximální velikosti souboru v PHP: {maxUploadSize} MB',
    'Password' => 'Heslo',
    'Port' => 'Port',
    'Port number' => 'Port',
    'Save' => 'Uložit',
    'Save & Flush Caches' => 'Uložit a vyčistit cache',
    'Save & Test' => 'Uložit a vyzkoušet',
    'Saved' => 'Uloženo',
    'Saved and flushed cache' => 'Uloženo, cache vyprázdněna',
    'Server' => 'Server',
    'Server Timezone' => 'Časové pásmo serveru',
    'Show introduction tour for new users' => 'Zobrazit novým uživatelům úvodní prohlídku',
    'Show user profile post form on dashboard' => 'Zobrazit na Nástěnce formulář pro odeslání nového příspěvku',
    'Sort by creation date' => 'Seřadit podle data vytvoření',
    'Sort by update date' => 'Seřadit podle data úpravy',
    'Theme' => 'Vzhled',
    'These settings refer to advanced topics of your social network.' => 'Tato nastavení se vztahují k pokročilým tématům Vaší sítě.',
    'These settings refer to the appearance of your social network.' => 'Tato nastavení se vztahují k nastavení vzhledu Vaší sítě.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Pro URL použijte proměnnou %url%. Formát dat musí být JSON. (např. ttp://www.youtube.com/oembed?url=%url%&format=json)',
    'Use X-Sendfile for File Downloads' => 'Pro stahování souborů použít metodu X-Sendfile',
    'User' => 'Uživatel',
    'User Settings' => 'Uživatelská nastavení',
    'Username' => 'Uživatelské jméno',
    'Username (e.g. john)' => 'Uživatelské jméno (např. jannovak)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Můžete přidat kousek HTML kódu, který se přidá ke všem dosavadním stránkám.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'V tuto chvíli se nezobrazuje žádné logo. Můžete nějaké nahrát.',
    'never' => 'nikdy',
    '"My Spaces" Sorting' => '',
    '<strong>Confirm</strong> icon deletion' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Activate' => '',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Could not send test email.' => '',
    'Custom DSN' => '',
    'Custom sort order (alphabetical if not defined)' => '',
    'Custom sort order can be defined in the Space advanced settings.' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Deactivate' => '',
    'Deactivate maintenance mode and enable all users to access the platform again?' => '',
    'Default Timezone' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Exclude media files from stream attachment list' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Maintenance mode' => '',
    'Mobile appearance' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Reported database time: {dateTime}' => '',
    'Saved and sent test email to: {address}' => '',
    'Test message' => '',
    'Url Pattern' => '',
    'Use SMTPS' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/admin/messages/cs/settings.php <==
<?php

return [
    '"My Spaces" Sorting' => 'Řazení "Mých prostorů"',
    '1 month' => '1 měsíc',
    '1 week' => '1 týden',
    '1 year' => '1 rok',
    '2 weeks' => '2 týdny',
    '3 months' => '3 měsíce',
    '6 months' => '6 měsíců',
    '<strong>Confirm</strong> image deletion' => '<strong>Potvrzení </strong> smazání obrázku',
    'APC(u)' => 'APC(u)',
    'Add OEmbed provider' => 'Přidat poskytovatele oEmbed',
    'Add new provider' => 'Přidat nového ověřovatele',
    'Advanced Settings' => 'Rozšířená nastavení',
    'Allow Self-Signed Certificates?' => 'Povolit Self-Signed certifikáty?',
    'Allowed file extensions' => 'Povolené přípony souborů',
    'Appearance Settings' => 'Nastavení vzhledu',
    'Auto format based on user language - Example: {example}' => 'Automatická formát uživatelského jazyka - Přiklad: {example}',
    'Back to overview' => 'Zpět na přehled',
    'Base URL' => 'URL adresa',
    'Cache Backend' => 'Systém vyrovnávací paměti',
    'Comma separated list. Leave empty to allow all.' => 'Jednotlivé přípony oddělte čárkou. Pro povolení všech přípon nechejte prázdné.',
    'Currently no provider active!' => 'Momentálně není aktivní žádný ověřovatel!',
    'Currently there are {count} records in the database dating from {dating}.' => 'V současné době existují {count} záznamy v databázi datované od {dating}.',
    'Custom sort order (alphabetical if not defined)' => 'Vlastní řazení (abecední, pokud není definováno)',
    'Custom sort order can be defined in the Space advanced settings.' => 'Vlastní řazení lze definovat v rozšířeném nastavení Prostor.',
    'Dashboard' => 'Nástěnka',
    'Date input format' => 'Formát data',
    'Default Expire Time (in seconds)' => 'Výchozí doba expirace (v sekundách)',
    'Default language' => 'Výchozí jazyk',
    'Default pagination size (Entries per page)' => 'Výchozí stránkování (položek na stránku)',
    'Default stream content order' => 'Výchozí pořadí obsahu',
    'Delete' => 'Smazat',
    'E-Mail' => 'E-mail',
    'E-Mail sender address' => 'Adresa odesílatele',
    'E-Mail sender name' => 'Jméno odesílatele',
    'E.g. http://example.com/humhub' => 'Např. http://example.com/humhub',
    'Edit OEmbed provider' => 'Editovat poskytovatele oEmbed',
    'Enable user friendship system' => 'Povolit přátelství',
    'Enabled' => 'Povoleno',
    'Enabled OEmbed providers' => 'Povolení poskytovatelů služby oEmbed',
    'Endpoint Url' => 'URL veřejné API provozovatele',
    'File' => 'Soubor',
    'Firstname Lastname (e.g. John Doe)' => 'Jméno Příjmení (např. Jan Novák)',
    'Friendship' => 'Přátelství',
    'General' => 'Obecné',
    'General Settings' => 'Hlavní nastavení',
    'HTML tracking code' => 'Sledovací kód',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Zde můžete nastavit proces registrace a další uživatelská nastavení pro Vaší síť.',
    'Here you can configure basic settings of your social network.' => 'Zde můžete nastavit základní nastavení Vaší sítě.',
    'Horizontal scrolling images on a mobile device' => 'Horizontalní posun obrázků na mobilních zařízeních',
    'Last visit' => 'Poslední návštěva',
    'Logo upload' => 'Nahrát logo',
    'Mail Transport Type' => 'Typ přenosu',
    'Maximum allowed age for logs.' => 'Maximální povolená doba logování',
    'Maximum upload file size (in MB)' => 'Maximální velikost nahrávaného souboru (v MB)',
    'Name of the application' => 'Název aplikace',
    'No Proxy Hosts' => 'Bez hostování proxy',
    'No caching' => 'Bez paměti cash',
    'Notification Settings' => 'Nastavení upozornění',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Staré protokoly mohou podstatně zvýšit velikost vaší databáze a přitom poskytnout jen málo informací.',
    'PHP APC(u) Extension missing - Type not available!' => 'Chybí rozšíření PHP APC(u) - nedostupné!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'Nastavení maximální velikosti souboru v PHP: {maxUploadSize} MB',
    'Password' => 'Heslo',
    'Port' => 'Port',
    'Port number' => 'Číslo portu',
    'Save' => 'Uložit',
    'Save & Flush Caches' => 'Uložit a vyčistit cache',
    'Save & Test' => 'Uložit a vyzkoušet',
    'Saved' => 'Uloženo',
    'Saved and flushed cache' => 'Uloženo, cache vyprázdněna',
    'Server' => 'Server',
    'Show introduction tour for new users' => 'Zobrazit novým uživatelům úvodní prohlídku',
    'Show user profile post form on dashboard' => 'Zobrazit na Nástěnce formulář pro odeslání nového příspěvku',
    'Sort by creation date' => 'Seřadit podle data vytvoření',
    'Sort by update date' => 'Seřadit podle data úpravy',
    'Theme' => 'Vzhled',
    'These settings refer to advanced topics of your social network.' => 'Tato nastavení se vztahují k pokročilým tématům Vaší sítě.',
    'These settings refer to the appearance of your social network.' => 'Tato nastavení se vztahují k nastavení vzhledu Vaší sítě.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Pro URL použijte proměnnou %url%. Formát dat musí být JSON. (např. ttp://www.youtube.com/oembed?url=%url%&format=json)',
    'Use X-Sendfile for File Downloads' => 'Pro stahování souborů použít metodu X-Sendfile',
    'User' => 'Uživatel',
    'User Settings' => 'Uživatelská nastavení',
    'Username' => 'Uživatelské jméno',
    'Username (e.g. john)' => 'Uživatelské jméno (např. jannovak)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Můžete přidat kousek HTML kódu, který se přidá ke všem dosavadním stránkám.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'V tuto chvíli se nezobrazuje žádné logo. Můžete nějaké nahrát.',
    'never' => 'nikdy',
    '<strong>Confirm</strong> icon deletion' => '',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Add custom info text for maintenance mode. Displayed on the login page.' => '',
    'Add individual info text...' => '',
    'Configuration (Use settings from configuration file)' => '',
    'Could not send test email.' => '',
    'Custom DSN' => '',
    'DSN' => '',
    'DSN Examples:' => '',
    'Default Timezone' => '',
    'E-Mail reply-to' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Enable maintenance mode' => '',
    'Exclude media files from stream attachment list' => '',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
    'Icon upload' => '',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
    'Maintenance mode' => '',
    'Maintenance mode restricts access to the platform and immediately logs out all users except Admins.' => '',
    'Mobile appearance' => '',
    'No Delivery (Debug Mode, Save as file)' => '',
    'Optional. Default reply address for system emails like notifications.' => '',
    'PHP (Use settings of php.ini file)' => '',
    'Prevent client caching of following scripts' => '',
    'Provider Name' => '',
    'Redis' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Reported database time: {dateTime}' => '',
    'Saved and sent test email to: {address}' => '',
    'Test message' => '',
    'Url Pattern' => '',
    'Use SMTPS' => '',
    'User Display Name' => '',
    'User Display Name Subtitle' => '',
    'You can find more configuration options here:' => '',
    'You\'re using no icon at the moment. Upload your logo now.' => '',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => '',
    'e.g. localhost' => '',
    'e.g. smtps://user:pass@smtp.example.com:port' => '',
];
